@@ -42,7 +42,7 @@ KNOWN_REGIONS = {
         'elasticache': 'elasticache.ap-northeast-1.amazonaws.com',
         'elasticbeanstalk': 'elasticbeanstalk.ap-northeast-1.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.ap-northeast-1.amazonaws.com',
-        'elasticmapreduce': 'ap-northeast-1.elasticmapreduce.amazonaws.com',
+        'elasticmapreduce': 'elasticmapreduce.ap-northeast-1.amazonaws.com',
         'elastictranscoder': 'elastictranscoder.ap-northeast-1.amazonaws.com',
         'glacier': 'glacier.ap-northeast-1.amazonaws.com',
         'iot': 'iot.ap-northeast-1.amazonaws.com',
@@ -56,7 +56,7 @@ KNOWN_REGIONS = {
         's3': 's3.ap-northeast-1.amazonaws.com',
         'sdb': 'sdb.ap-northeast-1.amazonaws.com',
         'sns': 'sns.ap-northeast-1.amazonaws.com',
-        'sqs': 'ap-northeast-1.queue.amazonaws.com',
+        'sqs': 'sqs.ap-northeast-1.amazonaws.com',
         'storagegateway': 'storagegateway.ap-northeast-1.amazonaws.com',
         'streams.dynamodb': 'streams.dynamodb.ap-northeast-1.amazonaws.com',
         'sts': 'sts.ap-northeast-1.amazonaws.com',
@@ -77,7 +77,7 @@ KNOWN_REGIONS = {
         'elasticache': 'elasticache.ap-southeast-1.amazonaws.com',
         'elasticbeanstalk': 'elasticbeanstalk.ap-southeast-1.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.ap-southeast-1.amazonaws.com',
-        'elasticmapreduce': 'ap-southeast-1.elasticmapreduce.amazonaws.com',
+        'elasticmapreduce': 'elasticmapreduce.ap-southeast-1.amazonaws.com',
         'elastictranscoder': 'elastictranscoder.ap-southeast-1.amazonaws.com',
         'kinesis': 'kinesis.ap-southeast-1.amazonaws.com',
         'kms': 'kms.ap-southeast-1.amazonaws.com',
@@ -88,7 +88,7 @@ KNOWN_REGIONS = {
         's3': 's3.ap-southeast-1.amazonaws.com',
         'sdb': 'sdb.ap-southeast-1.amazonaws.com',
         'sns': 'sns.ap-southeast-1.amazonaws.com',
-        'sqs': 'ap-southeast-1.queue.amazonaws.com',
+        'sqs': 'sqs.ap-southeast-1.amazonaws.com',
         'storagegateway': 'storagegateway.ap-southeast-1.amazonaws.com',
         'streams.dynamodb': 'streams.dynamodb.ap-southeast-1.amazonaws.com',
         'sts': 'sts.ap-southeast-1.amazonaws.com',
@@ -112,7 +112,7 @@ KNOWN_REGIONS = {
         'elasticache': 'elasticache.ap-southeast-2.amazonaws.com',
         'elasticbeanstalk': 'elasticbeanstalk.ap-southeast-2.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.ap-southeast-2.amazonaws.com',
-        'elasticmapreduce': 'ap-southeast-2.elasticmapreduce.amazonaws.com',
+        'elasticmapreduce': 'elasticmapreduce.ap-southeast-2.amazonaws.com',
         'glacier': 'glacier.ap-southeast-2.amazonaws.com',
         'kinesis': 'kinesis.ap-southeast-2.amazonaws.com',
         'kms': 'kms.ap-southeast-2.amazonaws.com',
@@ -123,7 +123,7 @@ KNOWN_REGIONS = {
         's3': 's3.ap-southeast-2.amazonaws.com',
         'sdb': 'sdb.ap-southeast-2.amazonaws.com',
         'sns': 'sns.ap-southeast-2.amazonaws.com',
-        'sqs': 'ap-southeast-2.queue.amazonaws.com',
+        'sqs': 'sqs.ap-southeast-2.amazonaws.com',
         'storagegateway': 'storagegateway.ap-southeast-2.amazonaws.com',
         'streams.dynamodb': 'streams.dynamodb.ap-southeast-2.amazonaws.com',
         'sts': 'sts.ap-southeast-2.amazonaws.com',
@@ -149,7 +149,7 @@ KNOWN_REGIONS = {
         'rds': 'rds.cn-north-1.amazonaws.com.cn',
         's3': 's3.cn-north-1.amazonaws.com.cn',
         'sns': 'sns.cn-north-1.amazonaws.com.cn',
-        'sqs': 'cn-north-1.queue.amazonaws.com.cn',
+        'sqs': 'sqs.cn-north-1.amazonaws.com.cn',
         'storagegateway': 'storagegateway.cn-north-1.amazonaws.com.cn',
         'streams.dynamodb': 'streams.dynamodb.cn-north-1.amazonaws.com.cn',
         'sts': 'sts.cn-north-1.amazonaws.com.cn',
@@ -179,7 +179,7 @@ KNOWN_REGIONS = {
         'redshift': 'redshift.eu-central-1.amazonaws.com',
         's3': 's3.eu-central-1.amazonaws.com',
         'sns': 'sns.eu-central-1.amazonaws.com',
-        'sqs': 'eu-central-1.queue.amazonaws.com',
+        'sqs': 'sqs.eu-central-1.amazonaws.com',
         'storagegateway': 'storagegateway.eu-central-1.amazonaws.com',
         'streams.dynamodb': 'streams.dynamodb.eu-central-1.amazonaws.com',
         'sts': 'sts.eu-central-1.amazonaws.com',
@@ -205,7 +205,7 @@ KNOWN_REGIONS = {
         'elasticache': 'elasticache.eu-west-1.amazonaws.com',
         'elasticbeanstalk': 'elasticbeanstalk.eu-west-1.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.eu-west-1.amazonaws.com',
-        'elasticmapreduce': 'eu-west-1.elasticmapreduce.amazonaws.com',
+        'elasticmapreduce': 'elasticmapreduce.eu-west-1.amazonaws.com',
         'elastictranscoder': 'elastictranscoder.eu-west-1.amazonaws.com',
         'email': 'email.eu-west-1.amazonaws.com',
         'glacier': 'glacier.eu-west-1.amazonaws.com',
@@ -221,7 +221,7 @@ KNOWN_REGIONS = {
         's3': 's3.eu-west-1.amazonaws.com',
         'sdb': 'sdb.eu-west-1.amazonaws.com',
         'sns': 'sns.eu-west-1.amazonaws.com',
-        'sqs': 'eu-west-1.queue.amazonaws.com',
+        'sqs': 'sqs.eu-west-1.amazonaws.com',
         'ssm': 'ssm.eu-west-1.amazonaws.com',
         'storagegateway': 'storagegateway.eu-west-1.amazonaws.com',
         'streams.dynamodb': 'streams.dynamodb.eu-west-1.amazonaws.com',
@@ -243,14 +243,14 @@ KNOWN_REGIONS = {
         'elasticache': 'elasticache.sa-east-1.amazonaws.com',
         'elasticbeanstalk': 'elasticbeanstalk.sa-east-1.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.sa-east-1.amazonaws.com',
-        'elasticmapreduce': 'sa-east-1.elasticmapreduce.amazonaws.com',
+        'elasticmapreduce': 'elasticmapreduce.sa-east-1.amazonaws.com',
         'kms': 'kms.sa-east-1.amazonaws.com',
         'monitoring': 'monitoring.sa-east-1.amazonaws.com',
         'rds': 'rds.sa-east-1.amazonaws.com',
         's3': 's3.sa-east-1.amazonaws.com',
         'sdb': 'sdb.sa-east-1.amazonaws.com',
         'sns': 'sns.sa-east-1.amazonaws.com',
-        'sqs': 'sa-east-1.queue.amazonaws.com',
+        'sqs': 'sqs.sa-east-1.amazonaws.com',
         'storagegateway': 'storagegateway.sa-east-1.amazonaws.com',
         'streams.dynamodb': 'streams.dynamodb.sa-east-1.amazonaws.com',
         'sts': 'sts.sa-east-1.amazonaws.com',
@@ -295,14 +295,14 @@ KNOWN_REGIONS = {
         'mobileanalytics': 'mobileanalytics.us-east-1.amazonaws.com',
         'monitoring': 'monitoring.us-east-1.amazonaws.com',
         'opsworks': 'opsworks.us-east-1.amazonaws.com',
-        'rds': 'rds.amazonaws.com',
+        'rds': 'rds.us-east-1.amazonaws.com',
         'redshift': 'redshift.us-east-1.amazonaws.com',
         'route53': 'route53.amazonaws.com',
         'route53domains': 'route53domains.us-east-1.amazonaws.com',
         's3': 's3.us-east-1.amazonaws.com',
         'sdb': 'sdb.amazonaws.com',
         'sns': 'sns.us-east-1.amazonaws.com',
-        'sqs': 'queue.amazonaws.com',
+        'sqs': 'sqs.us-east-1.amazonaws.com',
         'ssm': 'ssm.us-east-1.amazonaws.com',
         'storagegateway': 'storagegateway.us-east-1.amazonaws.com',
         'streams.dynamodb': 'streams.dynamodb.us-east-1.amazonaws.com',
@@ -330,7 +330,7 @@ KNOWN_REGIONS = {
         'redshift': 'redshift.us-gov-west-1.amazonaws.com',
         's3': 's3.us-gov-west-1.amazonaws.com',
         'sns': 'sns.us-gov-west-1.amazonaws.com',
-        'sqs': 'us-gov-west-1.queue.amazonaws.com',
+        'sqs': 'sqs.us-gov-west-1.amazonaws.com',
         'sts': 'sts.us-gov-west-1.amazonaws.com',
         'swf': 'swf.us-gov-west-1.amazonaws.com',
     },
@@ -347,7 +347,7 @@ KNOWN_REGIONS = {
         'elasticache': 'elasticache.us-west-1.amazonaws.com',
         'elasticbeanstalk': 'elasticbeanstalk.us-west-1.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.us-west-1.amazonaws.com',
-        'elasticmapreduce': 'us-west-1.elasticmapreduce.amazonaws.com',
+        'elasticmapreduce': 'elasticmapreduce.us-west-1.amazonaws.com',
         'elastictranscoder': 'elastictranscoder.us-west-1.amazonaws.com',
         'glacier': 'glacier.us-west-1.amazonaws.com',
         'kinesis': 'kinesis.us-west-1.amazonaws.com',
@@ -358,7 +358,7 @@ KNOWN_REGIONS = {
         's3': 's3.us-west-1.amazonaws.com',
         'sdb': 'sdb.us-west-1.amazonaws.com',
         'sns': 'sns.us-west-1.amazonaws.com',
-        'sqs': 'us-west-1.queue.amazonaws.com',
+        'sqs': 'sqs.us-west-1.amazonaws.com',
         'storagegateway': 'storagegateway.us-west-1.amazonaws.com',
         'streams.dynamodb': 'streams.dynamodb.us-west-1.amazonaws.com',
         'sts': 'sts.us-west-1.amazonaws.com',
@@ -385,7 +385,7 @@ KNOWN_REGIONS = {
         'elasticbeanstalk': 'elasticbeanstalk.us-west-2.amazonaws.com',
         'elasticfilesystem': 'elasticfilesystem.us-west-2.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.us-west-2.amazonaws.com',
-        'elasticmapreduce': 'us-west-2.elasticmapreduce.amazonaws.com',
+        'elasticmapreduce': 'elasticmapreduce.us-west-2.amazonaws.com',
         'elastictranscoder': 'elastictranscoder.us-west-2.amazonaws.com',
         'email': 'email.us-west-2.amazonaws.com',
         'glacier': 'glacier.us-west-2.amazonaws.com',
@@ -400,7 +400,7 @@ KNOWN_REGIONS = {
         's3': 's3.us-west-2.amazonaws.com',
         'sdb': 'sdb.us-west-2.amazonaws.com',
         'sns': 'sns.us-west-2.amazonaws.com',
-        'sqs': 'us-west-2.queue.amazonaws.com',
+        'sqs': 'sqs.us-west-2.amazonaws.com',
         'ssm': 'ssm.us-west-2.amazonaws.com',
         'storagegateway': 'storagegateway.us-west-2.amazonaws.com',
         'streams.dynamodb': 'streams.dynamodb.us-west-2.amazonaws.com',
